#[non_exhaustive]pub struct TypedPolicySystemControl {
pub id: String,
pub name: Option<String>,
pub authority: Option<String>,
pub assurance: Option<String>,
pub mandatory: bool,
pub description: Option<String>,
pub obligations: Vec<Value>,
}Expand description
One shipped control, with what happens when it cannot be evaluated.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Stringname: Option<String>assurance: Option<String>enforcement, gating_risk or advisory.
mandatory: boolWhether an organization may not override it. The platform omits the
member when it is false, so absent reads as false.
description: Option<String>obligations: Vec<Value>Trait Implementations
Sourceimpl Clone for TypedPolicySystemControl
impl Clone for TypedPolicySystemControl
Sourcefn clone(&self) -> TypedPolicySystemControl
fn clone(&self) -> TypedPolicySystemControl
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TypedPolicySystemControl
impl Debug for TypedPolicySystemControl
Sourceimpl Default for TypedPolicySystemControl
impl Default for TypedPolicySystemControl
Sourcefn default() -> TypedPolicySystemControl
fn default() -> TypedPolicySystemControl
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TypedPolicySystemControl
impl<'de> Deserialize<'de> for TypedPolicySystemControl
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TypedPolicySystemControl
impl PartialEq for TypedPolicySystemControl
Sourceimpl Serialize for TypedPolicySystemControl
impl Serialize for TypedPolicySystemControl
impl StructuralPartialEq for TypedPolicySystemControl